meshparty package
=================


trimesh\_io module
----------------------------
Mesh objects, and loading functionality

.. automodule:: meshparty.trimesh_io
   :members:
   :undoc-members:
   :show-inheritance:
   
mesh\_filters module
------------------------------
Functions for creating mesh masks

.. automodule:: meshparty.mesh_filters
   :members:
   :undoc-members:
   :show-inheritance:

trimesh\_repair module
--------------------------------
Functions for adding edges to meshes

.. automodule:: meshparty.trimesh_repair
   :members:
   :undoc-members:
   :show-inheritance:

skeletonize module
----------------------------
Functions for turnings meshes into skeletons

.. automodule:: meshparty.skeletonize
   :members:
   :undoc-members:
   :show-inheritance:

skeleton module
-------------------------
Skeleton class with useful methods for skeleton analysis

.. automodule:: meshparty.skeleton
   :members:
   :undoc-members:
   :show-inheritance:

skeleton\_io module
-----------------------------
Functions for reading and writing skeletons to disk

.. automodule:: meshparty.skeleton_io
   :members:
   :undoc-members:
   :show-inheritance:

trimesh\_vtk module
-----------------------------
Functions for creating vtk objects and visualizing meshes, skeletons and points

.. automodule:: meshparty.trimesh_vtk
   :members:
   :undoc-members:
   :show-inheritance:

utils module
----------------------
Utility functions used in other modules

.. automodule:: meshparty.utils
   :members:
   :undoc-members:
   :show-inheritance:

mesh_skel_utils module
----------------------
Functions for mapping skeletons and meshes together

.. automodule:: meshparty.mesh_skel_utils
   :members:
   :undoc-members:
   :show-inheritance:

meshlabserver module
------------------------------
Facilities for interacting with meshlab

.. automodule:: meshparty.meshlabserver
   :members:
   :undoc-members:
   :show-inheritance:

iterator module
-------------------------
Facilities for iterating over views of a mesh. Useful for ML applications.

.. automodule:: meshparty.iterator
   :members:
   :undoc-members:
   :show-inheritance: